@@ -11,34 +11,27 @@ from dovado_rtl.antlr.hdl_representation import (
 )
 from itertools import chain
 from typing import List, Tuple, Iterator, Union
-from dovado_rtl.antlr.generated.SysVerilogHDL.SysVerilogHDLVisitor import (
-    SysVerilogHDLVisitor,
+from dovado_rtl.antlr.generated.SystemVerilog.SystemVerilogParserVisitor import (
+    SystemVerilogParserVisitor,
 )
-from dovado_rtl.antlr.generated.SysVerilogHDL.SysVerilogHDLParser import (
-    SysVerilogHDLParser,
+from dovado_rtl.antlr.generated.SystemVerilog.SystemVerilogParser import (
+    SystemVerilogParser,
 )
 
 
-class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
+class SysVerilogHDLEntityVisitor(SystemVerilogParserVisitor):
     def __init__(self):
         self.entities: List[Entity] = []
         self.top_level = None
 
     def visitSource_text(
-        self, ctx: SysVerilogHDLParser.Source_textContext
+        self, ctx: SystemVerilogParser.Source_textContext
     ) -> None:
-        self.visitDescription_star(ctx.description_star())
-
-    def visitDescription_star(
-        self, ctx: SysVerilogHDLParser.Description_starContext
-    ) -> None:
-        if not ctx.description():
-            return
         for d in ctx.description():
             self.visitDescription(d)
 
     def visitDescription(
-        self, ctx: SysVerilogHDLParser.DescriptionContext
+        self, ctx: SystemVerilogParser.DescriptionContext
     ) -> None:
         if ctx.module_declaration():
             self.visitModule_declaration(ctx.module_declaration())
@@ -46,108 +39,166 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
             pass
 
     def visitModule_declaration(
-        self, ctx: SysVerilogHDLParser.Module_declarationContext
+        self, ctx: SystemVerilogParser.Module_declarationContext
     ) -> None:
+        if ctx.module_nonansi_header():
+            self.visitModule_nonansi_header(ctx.module_nonansi_header())
+        elif ctx.module_ansi_header():
+            self.visitModule_ansi_header(ctx.module_ansi_header())
+        else:
+            self.entities.append(
+                Entity(self.visitModule_identifier(ctx.module_identifier()[0]))
+            )
+
+    def visitModule_nonansi_header(
+        self, ctx: SystemVerilogParser.Module_nonansi_headerContext
+    ):
         self.entities.append(
             Entity(self.visitModule_identifier(ctx.module_identifier()))
         )
-        self.visitModule_interface(ctx.module_interface())
-        self.visitModule_item_star(ctx.module_item_star())
+        if ctx.parameter_port_list():
+            self.visitParameter_port_list(ctx.parameter_port_list())
+        print("Non-Ansi ports found, skipping...")
+        # self.visitList_of_ports(ctx.list_of_ports())
 
-    def visitModule_interface(
-        self, ctx: SysVerilogHDLParser.Module_interfaceContext
-    ) -> None:
-        if ctx.module_parameter_interface():
-            self.visitModule_parameter_interface(
-                ctx.module_parameter_interface()
+    def visitList_of_ports(
+        self, ctx: SystemVerilogParser.List_of_portsContext
+    ):
+        for i in ctx.port():
+            self.visitPort(i)
+
+    def visitList_of_port_declarations(
+        self, ctx: SystemVerilogParser.List_of_port_declarationsContext
+    ):
+        for i in ctx.ansi_port_declaration():
+            self.visitAnsi_port_declaration(i)
+
+    def visitAnsi_port_declaration(
+        self, ctx: SystemVerilogParser.Ansi_port_declarationContext
+    ):
+        direction = None
+        if ctx.net_port_header():
+            direction = self.visitNet_port_header(ctx.net_port_header())
+        if ctx.variable_port_header():
+            direction = self.visitVariable_port_header(
+                ctx.variable_port_header()
             )
-        if ctx.module_port_interface():
-            self.visitModule_port_interface(ctx.module_port_interface())
+        if ctx.port_direction():
+            direction = self.visitPort_direction()
+        if direction:
+            ident = self.visitPort_identifier(ctx.port_identifier())
 
-    def visitModule_parameter_interface(
-        self, ctx: SysVerilogHDLParser.Module_parameter_interfaceContext
-    ) -> None:
-        if ctx.list_of_interface_parameters():
-            self.visitList_of_interface_parameters(
-                ctx.list_of_interface_parameters()
-            )
+            self.entities[-1].add_port(Port(ident, direction, None))
 
-    def visitModule_port_interface(
-        self, ctx: SysVerilogHDLParser.Module_port_interfaceContext
-    ) -> None:
-        if ctx.list_of_interface_ports():
-            self.visitList_of_interface_ports(ctx.list_of_interface_ports())
+    def visitNet_port_header(
+        self, ctx: SystemVerilogParser.Net_port_headerContext
+    ):
+        if ctx.port_direction():
+            return self.visitPort_direction(ctx.port_direction())
+        return None
 
-    def visitList_of_interface_ports(
-        self, ctx: SysVerilogHDLParser.List_of_interface_portsContext
-    ) -> None:
-        if ctx.list_of_port_identifiers():
-            self.visitList_of_port_identifiers(ctx.list_of_port_identifiers())
+    def visitVariable_port_header(
+        self, ctx: SystemVerilogParser.Variable_port_headerContext
+    ):
+        if ctx.port_direction():
+            return self.visitPort_direction(ctx.port_direction())
+        return None
+
+    def visitPort_direction(
+        self, ctx: SystemVerilogParser.Port_directionContext
+    ):
+        if ctx.KINPUT():
+            return PortDirection(PortDirectionEnum.INPUT, descriptor="input")
+        if ctx.KOUTPUT():
+            return PortDirection(PortDirectionEnum.OUTPUT, descriptor="output")
+        if ctx.KINOUT():
+            return PortDirection(PortDirectionEnum.OTHER, descriptor="inout")
+        return None
+
+    def visitModule_ansi_header(
+        self, ctx: SystemVerilogParser.Module_ansi_headerContext
+    ):
+        self.entities.append(
+            Entity(self.visitModule_identifier(ctx.module_identifier()))
+        )
+        if ctx.parameter_port_list():
+            self.visitParameter_port_list(ctx.parameter_port_list())
         if ctx.list_of_port_declarations():
             self.visitList_of_port_declarations(
                 ctx.list_of_port_declarations()
             )
 
-    def visitList_of_port_declarations(
-        self, ctx: SysVerilogHDLParser.List_of_port_declarationsContext
-    ) -> None:
-        if ctx.list_of_port_declarations_comma():
-            self.visitList_of_port_declarations_comma(
-                ctx.list_of_port_declarations_comma()
-            )
-        if ctx.list_of_port_declarations_semicolon():
-            self.visitList_of_port_declarations_semicolon(
-                ctx.list_of_port_declarations_semicolon()
+    def visitParameter_port_list(
+        self, ctx: SystemVerilogParser.Parameter_port_listContext
+    ):
+        for i in ctx.parameter_port_declaration():
+            self.visitParameter_port_declaration(i)
+        if ctx.list_of_param_assignments():
+            self.visitList_of_param_assignments(
+                ctx.list_of_param_assignments()
             )
 
-    def visitList_of_port_declarations_comma(
-        self, ctx: SysVerilogHDLParser.List_of_port_declarations_commaContext
+    def visitList_of_param_assignments(
+        self, ctx: SystemVerilogParser.List_of_param_assignmentsContext
+    ):
+        for i in ctx.param_assignment():
+            yield self.visitParam_assignment(i)
+
+    def visitParam_assignment(
+        self, ctx: SystemVerilogParser.Param_assignmentContext
+    ):
+
+        return self.visitParameter_identifier(ctx.parameter_identifier())
+
+    def visitParameter_identifier(
+        self, ctx: SystemVerilogParser.Parameter_identifierContext
+    ):
+        return self.visitIdentifier(ctx.identifier())
+
+    def visitParameter_port_declaration(
+        self, ctx: SystemVerilogParser.Parameter_port_declarationContext
+    ):
+        if ctx.parameter_declaration():
+            self.visitParameter_declaration(ctx.parameter_declaration())
+
+    def visitList_of_port_declarations(
+        self, ctx: SystemVerilogParser.List_of_port_declarationsContext
     ) -> None:
+        for p in ctx.ansi_port_declaration():
+            self.visitAnsi_port_declaration(p)
+
+    def visitList_of_port_declarations_comma(self, ctx) -> None:
         self.visitAttr_port_declaration(ctx.attr_port_declaration())
         self.visitComma_attr_port_declaration_star(
             ctx.comma_attr_port_declaration_star()
         )
 
-    def visitComma_attr_port_declaration_star(
-        self, ctx: SysVerilogHDLParser.Comma_attr_port_declaration_starContext
-    ) -> None:
+    def visitComma_attr_port_declaration_star(self, ctx) -> None:
         if not ctx.comma_attr_port_declaration():
             return
         for a in ctx.comma_attr_port_declaration():
             self.visitComma_attr_port_declaration(a)
 
-    def visitComma_attr_port_declaration(
-        self, ctx: SysVerilogHDLParser.Comma_attr_port_declarationContext
-    ) -> None:
+    def visitComma_attr_port_declaration(self, ctx) -> None:
         self.visitAttr_port_declaration(ctx.attr_port_declaration())
 
-    def visitList_of_port_declarations_semicolon(
-        self,
-        ctx: SysVerilogHDLParser.List_of_port_declarations_semicolonContext,
-    ) -> None:
+    def visitList_of_port_declarations_semicolon(self, ctx) -> None:
         self.visitAttr_port_declaration_semicolon_plus(
             ctx.attr_port_declaration_semicolon_plus()
         )
 
-    def visitAttr_port_declaration_semicolon_plus(
-        self,
-        ctx: SysVerilogHDLParser.Attr_port_declaration_semicolon_plusContext,
-    ) -> None:
+    def visitAttr_port_declaration_semicolon_plus(self, ctx) -> None:
         for a in ctx.attr_port_declaration_semicolon():
             self.visitAttr_port_declaration_semicolon(a)
 
-    def visitAttr_port_declaration_semicolon(
-        self, ctx: SysVerilogHDLParser.Attr_port_declaration_semicolonContext
-    ) -> None:
+    def visitAttr_port_declaration_semicolon(self, ctx) -> None:
         self.visitAttr_port_declaration(ctx.attr_port_declaration())
 
-    def visitAttr_port_declaration(
-        self, ctx: SysVerilogHDLParser.Attr_port_declarationContext
-    ) -> None:
+    def visitAttr_port_declaration(self, ctx) -> None:
         self.visitPort_declaration(ctx.port_declaration())
 
     def visitPort_declaration(
-        self, ctx: SysVerilogHDLParser.Port_declarationContext
+        self, ctx: SystemVerilogParser.Port_declarationContext
     ) -> None:
         if ctx.inout_declaration():
             self.visitInout_declaration(ctx.inout_declaration())
@@ -159,146 +210,59 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
             print("Ref ports not supported, skipping")
 
     def visitInout_declaration(
-        self, ctx: SysVerilogHDLParser.Inout_declarationContext
+        self, ctx: SystemVerilogParser.Inout_declarationContext
     ) -> None:
-        self.visitInout_description(ctx.inout_description())
-
-    def visitInput_declaration(
-        self, ctx: SysVerilogHDLParser.Input_declarationContext
-    ) -> None:
-        self.visitInput_description(ctx.input_description())
-
-    def visitOutput_declaration(
-        self, ctx: SysVerilogHDLParser.Output_declarationContext
-    ) -> None:
-        self.visitOutput_description(ctx.output_description())
-
-    def visitInout_description(
-        self, ctx: SysVerilogHDLParser.Inout_descriptionContext
-    ) -> None:
-        for p in self.visitPort_description(ctx.port_description()):
+        for ident in self.visitList_of_port_identifiers(
+            ctx.list_of_port_identifiers()
+        ):
             self.entities[-1].add_port(
                 Port(
-                    p[0], PortDirection(PortDirectionEnum.OTHER, "inout"), p[1]
+                    ident,
+                    PortDirection(PortDirectionEnum.OTHER, "inout"),
+                    None,
                 )
             )
 
-    def visitInput_description(
-        self, ctx: SysVerilogHDLParser.Input_descriptionContext
-    ):
-        if ctx.port_description():
-            self.visitPort_description(ctx.port_description())
-        for d in chain(
-            self.visitLogic_declaration(ctx.logic_declaration())
-            if ctx.logic_declaration()
-            else iter(()),
-            self.visitInteger_declaration(ctx.integer_declaration())
-            if ctx.integer_declaration()
-            else iter(()),
-            self.visitInt_declaration(ctx.int_declaration())
-            if ctx.int_declaration()
-            else iter(()),
-            self.visitTime_declaration(ctx.time_declaration())
-            if ctx.time_declaration()
-            else iter(()),
-            self.visitNet_declaration(ctx.net_declaration())
-            if ctx.net_declaration()
-            else iter(()),
-            self.visitBits_declaration(ctx.bits_declaration())
-            if ctx.bits_declaration()
-            else iter(()),
+    def visitInput_declaration(
+        self, ctx: SystemVerilogParser.Input_declarationContext
+    ) -> None:
+        for ident in self.visitList_of_port_identifiers(
+            ctx.list_of_port_identifiers()
         ):
-            p_type = d[1]
-            if isinstance(p_type, PortType):
-                self.entities[-1].add_port(
-                    Port(
-                        d[0],
-                        PortDirection(PortDirectionEnum.INPUT, "input"),
-                        p_type,
-                    )
+            self.entities[-1].add_port(
+                Port(
+                    ident,
+                    PortDirection(PortDirectionEnum.INPUT, "input"),
+                    None,
                 )
+            )
 
-    def visitOutput_description(
-        self, ctx: SysVerilogHDLParser.Output_descriptionContext
-    ):
-        if ctx.port_description():
-            for p in self.visitPort_description(ctx.port_description()):
-                self.entities[-1].add_port(
-                    Port(
-                        p[0],
-                        PortDirection(PortDirectionEnum.OUTPUT, "output"),
-                        p[1],
-                    )
-                )
-
-        for d in chain(
-            self.visitLogic_declaration(ctx.logic_declaration())
-            if ctx.logic_declaration()
-            else iter(()),
-            self.visitInteger_declaration(ctx.integer_declaration())
-            if ctx.integer_declaration()
-            else iter(()),
-            self.visitTime_declaration(ctx.time_declaration())
-            if ctx.time_declaration()
-            else iter(()),
-            self.visitNet_declaration(ctx.net_declaration())
-            if ctx.net_declaration()
-            else iter(()),
+    def visitOutput_declaration(
+        self, ctx: SystemVerilogParser.Output_declarationContext
+    ) -> None:
+        for ident in self.visitList_of_port_identifiers(
+            ctx.list_of_port_identifiers()
         ):
-            p_type = d[1]
-            if isinstance(p_type, PortType):
-                self.entities[-1].add_port(
-                    Port(
-                        d[0],
-                        PortDirection(PortDirectionEnum.OUTPUT, "output"),
-                        p_type,
-                    )
+            self.entities[-1].add_port(
+                Port(
+                    ident,
+                    PortDirection(PortDirectionEnum.OUTPUT, "output"),
+                    None,
                 )
-            else:
-                pass
-
-    def visitPort_description(
-        self, ctx: SysVerilogHDLParser.Port_descriptionContext
-    ) -> Iterator[Tuple[str, PortType]]:
-        if ctx.Signed():
-            for v in ctx.list_of_variable_descriptions():
-                yield v, PortType(PortTypeEnum.VECTOR, "Signed")
-        if ctx.Unsigned():
-            for v in ctx.list_of_variable_descriptions():
-                yield v, PortType(PortTypeEnum.VECTOR, "Unsigned")
-        else:
-            for v in ctx.list_of_variable_descriptions():
-                yield v, PortType(PortTypeEnum.VECTOR, "")
+            )
 
     def visitList_of_port_identifiers(
-        self, ctx: SysVerilogHDLParser.List_of_port_identifiersContext
+        self, ctx: SystemVerilogParser.List_of_port_identifiersContext
     ) -> None:
-        self.visitPort_identifier(ctx.port_identifier())
-        self.visitComma_port_identifier_star(ctx.comma_port_identifier_star())
-
-    def visitComma_port_identifier_star(
-        self, ctx: SysVerilogHDLParser.Comma_port_identifier_starContext
-    ) -> None:
-        if not ctx.comma_port_identifier():
-            return
-        for i in ctx.comma_port_identifier():
-            self.visitComma_port_identifier(i)
-
-    def visitComma_port_identifier(
-        self, ctx: SysVerilogHDLParser.Comma_port_identifierContext
-    ) -> None:
-        self.visitPort_identifier(ctx.port_identifier())
+        for i in self.visitPort_identifier(ctx.port_identifier()):
+            yield self.visitPort_identifier(i)
 
     def visitPort_identifier(
-        self, ctx: SysVerilogHDLParser.Port_identifierContext
-    ) -> None:
-        self.entities[-1].add_port(
-            Port(self.visitIdentifier(ctx.identifier()), None, None)
-        )
+        self, ctx: SystemVerilogParser.Port_identifierContext
+    ) -> str:
+        return self.visitIdentifier(ctx.identifier())
 
-    def visitList_of_interface_parameters(
-        self, ctx: SysVerilogHDLParser.List_of_interface_parametersContext
-    ) -> None:
+    def visitList_of_interface_parameters(self, ctx) -> None:
         if ctx.list_of_parameter_declarations():
             self.visitList_of_parameter_declarations(
                 ctx.list_of_parameter_declarations()
@@ -308,35 +272,58 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
                 ctx.list_of_parameter_descriptions()
             )
 
-    def visitList_of_parameter_declarations(
-        self, ctx: SysVerilogHDLParser.List_of_parameter_declarationsContext
-    ) -> None:
+    def visitList_of_parameter_declarations(self, ctx) -> None:
         self.visitParameter_declaration(ctx.parameter_declaration())
         self.visitComma_parameter_declaration_star(
             ctx.comma_parameter_declaration_star()
         )
 
-    def visitComma_parameter_declaration_star(
-        self, ctx: SysVerilogHDLParser.Comma_parameter_declaration_starContext
-    ) -> None:
+    def visitComma_parameter_declaration_star(self, ctx) -> None:
         if not ctx.comma_parameter_declaration():
             return
         for p in ctx.comma_parameter_declaration():
             self.visitComma_parameter_declaration(p)
 
-    def visitComma_parameter_declaration(
-        self, ctx: SysVerilogHDLParser.Comma_parameter_declarationContext
-    ) -> None:
+    def visitComma_parameter_declaration(self, ctx) -> None:
         self.visitParameter_declaration(ctx.parameter_declaration())
 
     def visitParameter_declaration(
-        self, ctx: SysVerilogHDLParser.Parameter_declarationContext
+        self, ctx: SystemVerilogParser.Parameter_declarationContext
     ) -> None:
-        self.visitParam_description(ctx.param_description())
+        param_type = self.visitData_type_or_implicit(
+            ctx.data_type_or_implicit()
+        )
+        if param_type:
+            for param in self.visitList_of_param_assignments(
+                ctx.list_of_param_assignments()
+            ):
+                self.entities[-1].add_parameter(
+                    Parameter(str(param), param_type)
+                )
 
-    def visitParam_description(
-        self, ctx: SysVerilogHDLParser.Param_descriptionContext
-    ) -> None:
+    def visitData_type(self, ctx: SystemVerilogParser.Data_typeContext):
+        if ctx.integer_atom_type():
+            return self.visitInteger_atom_type(ctx.integer_atom_type())
+        else:
+            return None
+
+    def visitInteger_atom_type(
+        self, ctx: SystemVerilogParser.Integer_atom_typeContext
+    ):
+        if ctx.KBYTE():
+            return ParameterType(ParameterTypeEnum.INTEGER, "byte")
+        if ctx.KSHORTINT():
+            return ParameterType(ParameterTypeEnum.INTEGER, "shortint")
+        if ctx.KINT():
+            return ParameterType(ParameterTypeEnum.INTEGER, "int")
+        if ctx.KLONGINT():
+            return ParameterType(ParameterTypeEnum.INTEGER, "longint")
+        if ctx.KINTEGER():
+            return ParameterType(ParameterTypeEnum.INTEGER, "integer")
+        if ctx.KTIME():
+            return ParameterType(ParameterTypeEnum.INTEGER, "time")
+
+    def visitParam_description(self, ctx) -> None:
         if ctx.param_declaration():
             for v in self.visitParam_declaration(ctx.param_declaration()):
                 self.entities[-1].add_parameter(Parameter(v[0], v[1]))
@@ -362,9 +349,7 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
             # non numeric or non synthesizable types skipped
             pass
 
-    def visitParam_declaration(
-        self, ctx: SysVerilogHDLParser.Param_declarationContext
-    ) -> List[Tuple[str, ParameterType]]:
+    def visitParam_declaration(self, ctx) -> List[Tuple[str, ParameterType]]:
         out = []
         if ctx.Signed():
             for v in self.visitList_of_hierarchical_variable_descriptions(
@@ -388,7 +373,7 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
         return out
 
     def visitBits_declaration(
-        self, ctx: SysVerilogHDLParser.Bits_declarationContext
+        self, ctx
     ) -> Iterator[Tuple[str, ParameterType]]:
         for v in self.visitList_of_variable_descriptions(
             ctx.list_of_variable_descriptions()
@@ -398,14 +383,14 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
             b_type += "unsigned" if ctx.Unsigned() else ""
             yield v, ParameterType(ParameterTypeEnum.INTEGER, b_type)
 
-    def visitBits_type(self, ctx: SysVerilogHDLParser.Bits_typeContext) -> str:
+    def visitBits_type(self, ctx) -> str:
         if ctx.Bit():
             return ctx.Bit().getText()
         else:
             return ctx.Byte().getText()
 
     def visitNet_declaration(
-        self, ctx: SysVerilogHDLParser.Net_declarationContext
+        self, ctx: SystemVerilogParser.Net_declarationContext
     ) -> Iterator[Tuple[str, PortType]]:
         for v in self.visitList_of_variable_descriptions(
             ctx.list_of_variable_descriptions()
@@ -419,7 +404,7 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
             yield v, PortType(net.type, p_type)
 
     def visitNet_type(
-        self, ctx: SysVerilogHDLParser.Net_typeContext
+        self, ctx: SystemVerilogParser.Net_typeContext
     ) -> PortType:
         if ctx.Supply0():
             return PortType(PortTypeEnum.VECTOR, ctx.Supply0().getText())
@@ -448,7 +433,7 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
         return PortType(PortTypeEnum.VECTOR, ctx.NONE().getText())
 
     def visitLogic_declaration(
-        self, ctx: SysVerilogHDLParser.Logic_declarationContext
+        self, ctx
     ) -> Union[
         Iterator[Tuple[str, ParameterType]], Iterator[Tuple[str, PortType]]
     ]:
@@ -457,7 +442,7 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
         ):
             if isinstance(
                 ctx.parentCtx.parentCtx.parentCtx,
-                SysVerilogHDLParser.Port_declarationContext,
+                SystemVerilogParser.Port_declarationContext,
             ):
                 yield v, PortType(PortTypeEnum.SCALAR, "Logic")
 
@@ -465,7 +450,7 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
                 yield v, ParameterType(ParameterTypeEnum.INTEGER, "Logic")
 
     def visitInteger_declaration(
-        self, ctx: SysVerilogHDLParser.Integer_declarationContext
+        self, ctx
     ) -> Union[
         Iterator[Tuple[str, ParameterType]], Iterator[Tuple[str, PortType]]
     ]:
@@ -478,14 +463,14 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
             p_type += "unsigned" if ctx.Unsigned() else ""
             if isinstance(
                 ctx.parentCtx.parentCtx.parentCtx,
-                SysVerilogHDLParser.Port_declarationContext,
+                SystemVerilogParser.Port_declarationContext,
             ):
                 yield v, PortType(PortTypeEnum.SCALAR, p_type)
             else:
                 yield v, ParameterType(ParameterTypeEnum.INTEGER, p_type)
 
     def visitInt_declaration(
-        self, ctx: SysVerilogHDLParser.Int_declarationContext
+        self, ctx
     ) -> Union[
         Iterator[Tuple[str, ParameterType]], Iterator[Tuple[str, PortType]]
     ]:
@@ -501,14 +486,14 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
             p_type += "unsigned" if ctx.Unsigned() else ""
             if isinstance(
                 ctx.parentCtx.parentCtx.parentCtx,
-                SysVerilogHDLParser.Port_declarationContext,
+                SystemVerilogParser.Port_declarationContext,
             ):
                 yield v, PortType(PortTypeEnum.SCALAR, p_type)
             else:
                 yield v, ParameterType(ParameterTypeEnum.INTEGER, p_type)
 
     def visitTime_declaration(
-        self, ctx: SysVerilogHDLParser.Time_declarationContext
+        self, ctx
     ) -> Union[
         Iterator[Tuple[str, ParameterType]], Iterator[Tuple[str, PortType]]
     ]:
@@ -518,15 +503,14 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
         ):
             if isinstance(
                 ctx.parentCtx.parentCtx.parentCtx,
-                SysVerilogHDLParser.Port_declarationContext,
+                SystemVerilogParser.Port_declarationContext,
             ):
                 yield v, PortType(PortTypeEnum.SCALAR, "Time")
             else:
                 yield v, ParameterType(ParameterTypeEnum.INTEGER, "Time")
 
     def visitList_of_hierarchical_variable_descriptions(
-        self,
-        ctx: SysVerilogHDLParser.List_of_hierarchical_variable_descriptionsContext,
+        self, ctx
     ) -> List[str]:
         vds = self.visitHierarchical_variable_description(
             ctx.hierarchical_variable_description()
@@ -540,36 +524,30 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
         return vds
 
     def visitComma_hierarchical_variable_description_star(
-        self,
-        ctx: SysVerilogHDLParser.Comma_hierarchical_variable_description_starContext,
+        self, ctx
     ) -> List[str]:
         out = []
         for h in ctx.comma_hierarchical_variable_description():
             out.extend(self.visitComma_hierarchical_variable_description(h))
         return out
 
-    def visitComma_hierarchical_variable_description(
-        self,
-        ctx: SysVerilogHDLParser.Comma_hierarchical_variable_descriptionContext,
-    ) -> List[str]:
+    def visitComma_hierarchical_variable_description(self, ctx) -> List[str]:
         return self.visitHierarchical_variable_description(
             ctx.hierarchical_variable_description()
         )
 
-    def visitHierarchical_variable_description(
-        self, ctx: SysVerilogHDLParser.Hierarchical_variable_descriptionContext
-    ) -> List[str]:
+    def visitHierarchical_variable_description(self, ctx) -> List[str]:
         return self.visitHierarchical_variable_identifier(
             ctx.hierarchical_variable_identifier()
         )
 
     def visitHierarchical_variable_identifier(
-        self, ctx: SysVerilogHDLParser.Hierarchical_variable_identifierContext
+        self, ctx: SystemVerilogParser.Hierarchical_variable_identifierContext
     ) -> List[str]:
         return self.visitHierarchical_identifier(ctx.hierarchical_identifier())
 
     def visitHierarchical_identifier(
-        self, ctx: SysVerilogHDLParser.Hierarchical_identifierContext
+        self, ctx: SystemVerilogParser.Hierarchical_identifierContext
     ) -> List[str]:
         out = [
             self.visitHierarchical_identifier_branch_item(
@@ -584,30 +562,23 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
         return out
 
     def visitDot_hierarchical_identifier_branch_item_star(
-        self,
-        ctx: SysVerilogHDLParser.Dot_hierarchical_identifier_branch_item_starContext,
+        self, ctx
     ) -> List[str]:
         out = []
         for h in ctx.dot_hierarchical_identifier_branch_item():
             out.append(self.visitDot_hierarchical_identifier_branch_item(h))
         return out
 
-    def visitDot_hierarchical_identifier_branch_item(
-        self,
-        ctx: SysVerilogHDLParser.Dot_hierarchical_identifier_branch_itemContext,
-    ) -> str:
+    def visitDot_hierarchical_identifier_branch_item(self, ctx) -> str:
         return self.visitHierarchical_identifier_branch_item(
             ctx.hierarchical_identifier_branch_item()
         )
 
-    def visitHierarchical_identifier_branch_item(
-        self,
-        ctx: SysVerilogHDLParser.Hierarchical_identifier_branch_itemContext,
-    ):
+    def visitHierarchical_identifier_branch_item(self, ctx):
         return self.visitIdentifier(ctx.identifier())
 
     def visitList_of_variable_descriptions(
-        self, ctx: SysVerilogHDLParser.List_of_variable_descriptionsContext
+        self, ctx: SystemVerilogParser
     ) -> List[str]:
         vds = [self.visitVariable_description(ctx.variable_description())]
         vds.extend(
@@ -618,37 +589,30 @@ class SysVerilogHDLEntityVisitor(SysVerilogHDLVisitor):
         return vds
 
     def visitComma_variable_description_star(
-        self, ctx: SysVerilogHDLParser.Comma_variable_description_starContext
+        self, ctx: SystemVerilogParser
     ) -> List[str]:
         vds = []
         for v in ctx.comma_variable_description():
             vds.append(self.visitComma_variable_description(v))
         return vds
 
-    def visitComma_variable_description(
-        self, ctx: SysVerilogHDLParser.Comma_variable_descriptionContext
-    ) -> str:
+    def visitComma_variable_description(self, ctx: SystemVerilogParser) -> str:
         return self.visitVariable_description(ctx.variable_description())
 
-    def visitVariable_description(
-        self, ctx: SysVerilogHDLParser.Variable_descriptionContext
-    ) -> str:
+    def visitVariable_description(self, ctx: SystemVerilogParser) -> str:
         return self.visitVariable_identifier(ctx.variable_identifier())
 
     def visitVariable_identifier(
-        self, ctx: SysVerilogHDLParser.Variable_identifierContext
+        self, ctx: SystemVerilogParser.Variable_identifierContext
     ) -> str:
         return self.visitIdentifier(ctx.identifier())
 
     def visitModule_identifier(
-        self, ctx: SysVerilogHDLParser.Module_identifierContext
+        self, ctx: SystemVerilogParser.Module_identifierContext
     ) -> str:
         return self.visitIdentifier(ctx.identifier())
 
     def visitIdentifier(
-        self, ctx: SysVerilogHDLParser.IdentifierContext
+        self, ctx: SystemVerilogParser.IdentifierContext
     ) -> str:
-        if ctx.Simple_identifier():
-            return ctx.Simple_identifier().getText()
-        else:
-            return ctx.Escaped_identifier().getText()
+        return ctx.SIMPLE_IDENTIFIER().getText()
